@@ -182,11 +182,11 @@ dialog_show_callback (GtkWidget *widget, gpointer callback_data)
 
 	if (password_dialog->details->username_should_focus) {
 		/* Move the focus to the username entry */
-		nautilus_caption_table_entry_grab_focus (NAUTILUS_CAPTION_TABLE (password_dialog->details->table), 
+		ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
 							 CAPTION_TABLE_USERNAME_ROW);
 	} else {
 		/* Move the focus to the password entry */
-		nautilus_caption_table_entry_grab_focus (NAUTILUS_CAPTION_TABLE (password_dialog->details->table), 
+		ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
 							 CAPTION_TABLE_PASSWORD_ROW);
 	}
 }
@@ -318,7 +318,7 @@ ammonite_login_dialog_new	(EazelProxy_AuthnPromptKind prompt_kind,
 		/* 
 		 * The table that holds the captions
 		 */
-		password_dialog->details->table = nautilus_caption_table_new (2);
+		password_dialog->details->table = ammonite_caption_table_new (2);
 		
 		gtk_signal_connect (GTK_OBJECT (password_dialog->details->table),
 				   "activate",
@@ -330,16 +330,16 @@ ammonite_login_dialog_new	(EazelProxy_AuthnPromptKind prompt_kind,
 				   GTK_SIGNAL_FUNC (caption_table_tab_out_callback),
 				   (gpointer) password_dialog);
 	
-		nautilus_caption_table_set_row_info (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		ammonite_caption_table_set_row_info (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 						     CAPTION_TABLE_USERNAME_ROW,
-						     "User Name:",
+						     _("User Name:"),
 						     "",
 						     TRUE,
 						     TRUE);
 
-		nautilus_caption_table_set_row_info (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		ammonite_caption_table_set_row_info (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 						     CAPTION_TABLE_PASSWORD_ROW,
-						     "Password:",
+						     _("Password:"),
 						     "",
 						     FALSE,
 						     FALSE);
@@ -499,7 +499,7 @@ ammonite_login_dialog_set_username (AmmoniteLoginDialog	*password_dialog,
 	g_return_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (password_dialog));
 
 	if (password_dialog->details->table) {
-		nautilus_caption_table_set_entry_text (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		ammonite_caption_table_set_entry_text (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 						       CAPTION_TABLE_USERNAME_ROW,
 						       username);
 	}
@@ -513,7 +513,7 @@ ammonite_login_dialog_set_password (AmmoniteLoginDialog	*password_dialog,
 	g_return_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (password_dialog));
 	
 	if (password_dialog->details->table) {
-		nautilus_caption_table_set_entry_text (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		ammonite_caption_table_set_entry_text (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 						       CAPTION_TABLE_PASSWORD_ROW,
 						       password);
 	}
@@ -527,7 +527,7 @@ ammonite_login_dialog_set_readonly_username (AmmoniteLoginDialog	*password_dialo
 	g_return_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (password_dialog));
 	
 	if (password_dialog->details->table) {
-		nautilus_caption_table_set_entry_readonly (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		ammonite_caption_table_set_entry_readonly (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 							   CAPTION_TABLE_USERNAME_ROW,
 							   readonly);
 	}
@@ -540,7 +540,7 @@ ammonite_login_dialog_get_username (AmmoniteLoginDialog *password_dialog)
 	g_return_val_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (password_dialog), NULL);
 
 	if (password_dialog->details->table) {
-		return nautilus_caption_table_get_entry_text (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		return ammonite_caption_table_get_entry_text (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 							      CAPTION_TABLE_USERNAME_ROW);
 	} else {
 		return NULL;
@@ -554,7 +554,7 @@ ammonite_login_dialog_get_password (AmmoniteLoginDialog *password_dialog)
 	g_return_val_if_fail (NAUTILUS_IS_PASSWORD_DIALOG (password_dialog), NULL);
 
 	if (password_dialog->details->table) {
-		return nautilus_caption_table_get_entry_text (NAUTILUS_CAPTION_TABLE (password_dialog->details->table),
+		return ammonite_caption_table_get_entry_text (AMMONITE_CAPTION_TABLE (password_dialog->details->table),
 							      CAPTION_TABLE_PASSWORD_ROW);
 	} else {
 		return NULL;
