@@ -1,4 +1,4 @@
-/* $Id: http-connection.c,v 1.24 2001/02/23 12:23:35 seth Exp $
+/* $Id: http-connection.c,v 1.25 2001/02/28 01:16:24 mfleming Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -410,7 +410,7 @@ http_connection_connect (
 	}
 #endif
 
-	if (config.use_ssl && config.upstream_host) {
+	if (config.use_ssl && config.upstream_proxy) {
 		http_connection->proxy_connect = FALSE;
 		err = socket_connect_proxy_tunnel (
 			server_socket, 
@@ -420,7 +420,7 @@ http_connection_connect (
 			http_connection_sock_connect
 		);
 		success = (0 == err) ? FALSE : TRUE;
-	} else if (config.use_ssl && NULL == config.upstream_host ) {
+	} else if (config.use_ssl && NULL == config.upstream_proxy ) {
 		http_connection->proxy_connect = FALSE;
 		err = socket_connect_ssl (
 			server_socket, 
@@ -429,11 +429,11 @@ http_connection_connect (
 			http_connection_sock_connect
 		);
 		success = (0 == err) ? FALSE : TRUE;
-	} else if (!config.use_ssl && config.upstream_host) {
+	} else if (!config.use_ssl && config.upstream_proxy) {
 		http_connection->proxy_connect = TRUE;
 		err = socket_connect (
 			server_socket, 
-			config.upstream_host, 
+			config.upstream_proxy, 
 			config.upstream_port,
 			http_connection_sock_connect
 		);
