@@ -1,5 +1,5 @@
 
-/* $Id: impl-eazelproxy.c,v 1.70 2001/02/22 01:25:02 mfleming Exp $
+/* $Id: impl-eazelproxy.c,v 1.71 2001/02/28 01:16:24 mfleming Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -94,8 +94,7 @@ gboolean gl_user_level_have 		= FALSE;
 
 /* The current Eazel Services Machine id setting */
 /* exported for authenticate_add_default_headers:eazelproxy-authn.c */
-gchar * gl_machine_id;
-gboolean gl_machine_id_have 		= FALSE;
+gchar * gl_machine_id = NULL;
 
 /* The current OS distribution name, if available */
 gchar * gl_distribution_name;
@@ -203,7 +202,6 @@ generate_and_set_machine_id (void)
 
 	g_free (gl_machine_id);
 	gl_machine_id = g_strdup (machine_id_string);
-	gl_machine_id_have = TRUE;
 
 	gconf_engine_set_string (gl_gconf_engine, KEY_GCONF_TRILOBITE_MACHINE_ID, machine_id_string, NULL);
 	log ("new machine id, '%s'", machine_id_string);
@@ -212,20 +210,13 @@ generate_and_set_machine_id (void)
 static void
 configure_machine_id (void)
 {
-	GConfValue *val = NULL;
 
-	val = gconf_engine_get (gl_gconf_engine, KEY_GCONF_TRILOBITE_MACHINE_ID, NULL);
+	gl_machine_id = util_gconf_get_ensure_string (KEY_GCONF_TRILOBITE_MACHINE_ID);
 
-	if (NULL == val || GCONF_VALUE_STRING != val->type ) {
+	if (NULL == gl_machine_id) {
 		generate_and_set_machine_id ();
 	} else {
-		gl_machine_id = g_strdup (gconf_value_get_string (val));
-		gl_machine_id_have = TRUE;
 		log ("machine id is '%s'", gl_machine_id);
-	}	
-
-	if (val != NULL) {
-		gconf_value_free (val);
 	}
 }
 
@@ -1217,7 +1208,7 @@ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequestLine
 		*p_header_list = g_list_append (*p_header_list, g_strdup_printf ("X-Eazel-User-Level: %s", gl_user_level));
 	}
 
-	if (gl_machine_id_have) {
+	if (gl_machine_id != NULL) {
 		*p_header_list = g_list_append (*p_header_list, g_strdup_printf ("X-Eazel-Machine-ID: %s", gl_machine_id));
 	}
 
