@@ -1,4 +1,4 @@
-/* $Id: proxy.c,v 1.38 2001/02/13 04:13:11 mfleming Exp $
+/* $Id: proxy.c,v 1.39 2001/02/28 01:16:24 mfleming Exp $
  *
  * A trivial proxy server for relaying Eazel HTTP connections.  Sets up
  * initial config options, daemonizes if necessary, and then stays in a
@@ -79,7 +79,9 @@
 
 #define KEY_GCONF_DEFAULT_SSL_CERT "/apps/eazel-trilobite/ssl-cert"
 #define KEY_GCONF_DEFAULT_SSL_CERT_DIR "/apps/eazel-trilobite/ssl-cert-dir"
-#define KEY_GCONF_DEFAULT_DISABLE_SSL "/apps/eazel-trilobite/ssl-disable"
+#define KEY_GCONF_DISABLE_SSL "/apps/eazel-trilobite/ssl-disable"
+#define KEY_GCONF_SSL_CIPHER "/apps/eazel-trilobite/ssl-prefer-cipher"
+#define KEY_GCONF_SSL_IGNORE_SERVER_CERT "/apps/eazel-trilobite/ssl-ignore-server-cert"
 
 #define EAZEL_DEFAULT_CERT_DIR "/nautilus/certs"
 
@@ -255,10 +257,10 @@ watch_gconf_proxy_cb (const UtilGConfWatchVariable *watched,
 		&& 0 != strlen (gconf_value_get_string (val_proxy_host))
 		&& gconf_value_get_bool (val_use)
 	) {
-		g_free (config.upstream_host);
-		config.upstream_host = NULL;
+		g_free (config.upstream_proxy);
+		config.upstream_proxy = NULL;
 
-		config.upstream_host = g_strdup (gconf_value_get_string (val_proxy_host));
+		config.upstream_proxy = g_strdup (gconf_value_get_string (val_proxy_host));
 
 		if (NULL != val_proxy_port
 			&& GCONF_VALUE_INT == val_proxy_port->type
@@ -270,35 +272,39 @@ watch_gconf_proxy_cb (const UtilGConfWatchVariable *watched,
 		}
 
 		log("HTTP proxy changed to '%s:%d'", 
-			config.upstream_host, 
+			config.upstream_proxy, 
 			config.upstream_port
 		);
 	} else {
-		g_free (config.upstream_host);
-		config.upstream_host = NULL;
+		g_free (config.upstream_proxy);
+		config.upstream_proxy = NULL;
 		log ("HTTP proxy changed to <none>");
 	}
 }
 
+
 static void 
 load_gconf_defaults (void)
 {
-	static const UtilGConfWatchVariable to_watch[] = {
-		{KEY_GCONF_USE_HTTP_PROXY, GCONF_VALUE_BOOL, {NULL}, watch_gconf_proxy_cb},
-		{KEY_GCONF_HTTP_PROXY_HOST, GCONF_VALUE_STRING, {NULL}, watch_gconf_proxy_cb},
-		{KEY_GCONF_HTTP_PROXY_PORT, GCONF_VALUE_INT, {NULL}, watch_gconf_proxy_cb},
-		{KEY_GCONF_DEFAULT_SSL_CERT, GCONF_VALUE_STRING, {(gchar **)&gl_gconf_ssl_cert}, NULL},
-		{KEY_GCONF_DEFAULT_SSL_CERT_DIR, GCONF_VALUE_STRING, {(gchar **)&gl_gconf_ssl_cert_dir}, NULL},
-		{KEY_GCONF_DEFAULT_DISABLE_SSL, GCONF_VALUE_BOOL, {(gchar **) /*gboolean*/&gl_gconf_ssl_disabled}, NULL}
-	};
+	static const UtilGConfWatchVariable watchvar_use_http_proxy =
+		{KEY_GCONF_USE_HTTP_PROXY, GCONF_VALUE_BOOL, {NULL}, watch_gconf_proxy_cb};
 
-	if ( ! config.specified_upstream_host ) {
-		util_gconf_watch_variable (to_watch+0);
+	static const UtilGConfWatchVariable watchvar_http_proxy_host =
+		{KEY_GCONF_HTTP_PROXY_HOST, GCONF_VALUE_STRING, {NULL}, watch_gconf_proxy_cb};
+
+	static const UtilGConfWatchVariable watchvar_http_proxy_port =
+		{KEY_GCONF_HTTP_PROXY_PORT, GCONF_VALUE_INT, {NULL}, watch_gconf_proxy_cb};
+
+	if ( ! config.specified_upstream_proxy ) {
+		util_gconf_watch_variable (&watchvar_use_http_proxy);
+		util_gconf_watch_variable (&watchvar_http_proxy_host);
+		util_gconf_watch_variable (&watchvar_http_proxy_port);
 	}
 
-	/* FIXME these don't have to be watched because we don't do anything when they change */
-	util_gconf_watch_variable (to_watch+1);
-	util_gconf_watch_variable (to_watch+2);
+	gl_gconf_ssl_cert = util_gconf_get_ensure_string (KEY_GCONF_DEFAULT_SSL_CERT);
+	gl_gconf_ssl_cert_dir = util_gconf_get_ensure_string (KEY_GCONF_DEFAULT_SSL_CERT_DIR);
+
+	gl_gconf_ssl_disabled = util_gconf_get_ensure_bool (KEY_GCONF_DISABLE_SSL, FALSE);
 }
 
 #endif /*SIMPLE_PROXY*/
@@ -407,15 +413,15 @@ int main (int argc,
 			}
                         break;
 		case 'u':
-			config.specified_upstream_host = TRUE;
-			g_free (config.upstream_host);
-			config.upstream_host = g_strdup (poptGetOptArg (popt_context));
-			if (strlen (config.upstream_host) == 0) {
-				config.upstream_host = NULL;
+			config.specified_upstream_proxy = TRUE;
+			g_free (config.upstream_proxy);
+			config.upstream_proxy = g_strdup (poptGetOptArg (popt_context));
+			if (strlen (config.upstream_proxy) == 0) {
+				config.upstream_proxy = NULL;
 				break;
 			}
 
-			p = strchr (config.upstream_host, ':');
+			p = strchr (config.upstream_proxy, ':');
 			if (p) {
 				config.upstream_port = atoi (p+1);
 				*p = 0;
@@ -525,6 +531,13 @@ int main (int argc,
 				log ("Enabling SSL; using cert directory %s", DATADIR EAZEL_DEFAULT_CERT_DIR);
 				eazel_init_ssl (DATADIR EAZEL_DEFAULT_CERT_DIR, NULL );
 			}
+			ssl_set_preferred_cipher_list (util_gconf_get_ensure_string (KEY_GCONF_SSL_CIPHER));
+
+			/* WARNING: use of this option significantly compromises security */
+			if (util_gconf_get_ensure_bool (KEY_GCONF_SSL_IGNORE_SERVER_CERT, FALSE)) {
+				ssl_set_ignore_server_cert (TRUE);
+			}
+
 		}
 #endif
 		/* Exits on failure */
