@@ -9,9 +9,9 @@ typedef struct {
 	FILE *logf;
 	char *logf_name;
 	char *target_path;
-	char *upstream_host;
+	char *upstream_proxy;
 	int upstream_port;
-	gboolean specified_upstream_host;
+	gboolean specified_upstream_proxy;
 	char *local_host;
 	int local_port;
 	gboolean append_log;
