@@ -1,4 +1,4 @@
-/* $Id: request.c,v 1.43 2001/02/23 12:23:35 seth Exp $
+/* $Id: request.c,v 1.44 2001/02/28 01:16:24 mfleming Exp $
  *
  * Handles incoming request callbacks, buffers headers, and passes
  * the request on to the upstream server.
@@ -181,7 +181,7 @@ socket_connect_proxy_tunnel(
 
 	ret = socket_connect (
 		sock, 
-		config.upstream_host, 
+		config.upstream_proxy, 
 		config.upstream_port,
 		proxy_tunnel_sock_connect
 	);
@@ -692,7 +692,7 @@ proxy_handle_connect_method (Connection *conn, Socket *client_sock)
 
 	socket_set_data (conn->server, client_sock);
 	
-	if (config.upstream_host) {
+	if (config.upstream_proxy) {
 		err = socket_connect_proxy_tunnel (
 			conn->server, 
 			conn->request->host, 
