@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.20 2001/01/16 21:30:08 mfleming Exp $
+/* $Id: utils.c,v 1.21 2001/02/20 23:32:15 seth Exp $
  *
  * Misc. routines which are used by the various functions to handle strings
  * and memory allocation and pretty much anything else we can think of. Also,
@@ -156,7 +156,7 @@ int eazel_check_connection (int fd)
 	uid_t uid;
 
 	struct_length = sizeof (peer_name);
-	err = getpeername (fd, &peer_name, &struct_length);
+	err = getpeername (fd, (struct sockaddr *) &peer_name, &struct_length);
 
 	if (0 != err) {
 		log ("can't get peer name: %s", g_strerror(errno));
@@ -165,7 +165,7 @@ int eazel_check_connection (int fd)
 	}
 
 	struct_length = sizeof (our_name);
-	err = getsockname (fd, &our_name, &struct_length);
+	err = getsockname (fd, (struct sockaddr *) &our_name, &struct_length);
 	if (0 != err) {
 		log ("can't get local name: %s", g_strerror(errno));
 		result = 0;
